@import 'imports/colors';

ol.aep-breadcrumbs {
  margin-bottom: 0;

  .glue-breadcrumbs__item:not(:last-child)::after {
    color: $glue-grey-700;
    content: '»';
    margin-left: 3px;
    margin-right: 1px;
  }
}
