// Headers
.docs-component-main {
  h1,
  h2,
  h3,
  h4,
  h5,
  a[name] {
    // This creates a "fake block" above the header that does not show up
    // anywhere but tricks the browser into thinking that the anchor is 80px
    // higher than it actually is.
    cursor: default;
    outline: none;

    &::before {
      display: block;
      content: ' ';
      height: 80px;
      margin-top: -80px;
      pointer-events: none;
      visibility: hidden;
    }

    a {
      text-decoration: none;
    }
  }
  h4 {
    padding-bottom: 5px;

    &.aep-number {
      line-height: 1em;

      & + h1 {
        margin-top: 0px;
        margin-left: -2px;
      }
    }
  }
}
