<p id="aep-state-banner" class="callout note">
  This AEP is currently under review. This means that the editors have read it
  and are in high-level concurrence, and while it is not yet fully approved, we
  have a good faith expectation that the AEP will be approved in something
  close to its current state.
</p>
