{# This file generates the search content used by Tipur Search.
   The actual search implementation is in site/assets/js/search/
   See https://tipue.com/search -#}
var tipuesearch = {'pages': [
{% for aep in site.aeps.values() -%}
  {
    'title': {{ aep.title | striptags | tojson }},
    'text': {{ aep.content.html | striptags | tojson }},
    'tags': '',
    'url': '{{ site.relative_uri }}{{ aep.relative_uri }}',
  },
{% endfor -%}
]};
