<!DOCTYPE html>
<html lang="en-US">
  <meta charset="utf-8">
  <title>Redirecting&hellip;</title>
  <link rel="canonical" href="{{ site.base_url }}{{ target.relative_uri }}">
  <script>location="{{ site.base_url }}{{ target.relative_uri }}"</script>
  <meta http-equiv="refresh" content="0; url={{ site.base_url }}{{ target.relative_uri }}">
  <meta name="robots" content="noindex">
  <body>
    <h1>Redirecting&hellip;</h1>
    <a href="{{ site.base_url }}{{ target.relative_uri }}">Click here if you are not redirected.</a>
  </body>
</html>
