<p id="aep-state-banner" class="callout important">
  This AEP is no longer the best current practice.<br />
  It has been replaced by
  <a href="/{{ aep.replacement_id }}">AEP-{{ aep.replacement_id }}</a>.
</p>
