// Copyright 2019 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// This file contains JavaScript-applied rules that render graphviz objects
// in AEPs.
//
// Note: This script is not included in AEPs by default, because the scripts
// needed to render graphviz are nearly 1.5 MB in size that including them
// everywhere adds significant weight.
//
// See the front matter for AEP-1 or AEP-100 for examples of how to add this
// for AEPs that need graphviz rendering.
$.when($.ready).then(() => {
  $('.language-graphviz').each((_, el) => {
    let pre = $(el).children('pre');
    let graphviz = $(el).find('code').text();

    // Render a SVG and replace the original graphviz code with it.
    let viz = new Viz();
    viz.renderSVGElement(graphviz).then((svg) => {
      $('<p class="digraph"></p>').append(svg).insertBefore(pre);
      pre.remove();
    });
  });
});
