@import 'imports/colors';

.aep-hero {
  .aep-hero-banner {
    margin-top: 3em;
    border-bottom: 1px solid $glue-grey-300;

    .aep-hero-title {
      font-size: 250%;
      font-weight: bold;
    }
    .aep-hero-subtitle {
      font-size: 125%;
      margin-top: 1em;
    }

    .aep-buttons {
      padding-top: 2em;
      padding-bottom: 2em;

      > a {
        margin-right: 1em;
      }
    }
  }

  .aep-landing-content {
    padding-top: 1em;
    padding-bottom: 1em;
    border-bottom: 1px solid $glue-grey-300;

    h1 {
      font-size: 160%;
      font-weight: bold;
    }
    p {
      font-size: 115%;
    }
  }

  .aep-shortcuts {
    padding-top: 1em;

    .aep-shortcut {
      padding-top: 1em;

      > h1 {
        font-weight: bold;
        font-size: 120%;
      }

      > a {
        margin-top: 1em;
      }
    }
  }
}
